# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "BONES AND BORDERS",
]

DICT_SUB_STRUCTURES = {
    "BONES AND BORDERS":[
        'Bone',
        'Glenoid-Humerus Border'
        ]
}