# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "HREM 9.5",
    "MICRO CT",
]

DICT_SUB_STRUCTURES = {
    "HREM 9.5":[
        'AVC + LA',
        'Notochord',
        'OFT',
        'RV',
        'LV',
        'RA',
        'SFH'],
    
    "MICRO CT":['Gut',
                'Heart',
                'Liver',
                'Lungs',
                'Spleen',
                'Stomach']
}


    # "HREM":['Ao',
                # 'PA',
                # 'RV',
                # 'LV',
                # 'RA',
                # 'LA']