# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "DELTOID",
    "OTHER",
]

DICT_SUB_STRUCTURES = {
    "DELTOID":[
        'Anterior',
        'Lateral',
        'Posterior'],
    
    "OTHER":['Other']
}