# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "LARVA",
]

DICT_SUB_STRUCTURES = {
    "LARVA":[
        'Central nervous system',
        'Eye antennal discs',
        'Fat body',
        'Gonads',
        'Gut',
        'Haltere discs',
        'Leg discs',
        'Malphigian tubules', 
        'Mouth hook',
        'Muscles',
        'Salivary glands', 
        'Wings discs']
}